==> rustc_1.86.0+dfsg1.orig.tar.xz: rustc-1.86.0-src/src/tools/rustc-perf/collector/compile-benchmarks/stm32f4-0.14.0/src/stm32f446/otg_fs_global/otg_cid.rs <==
#[doc = "Register `OTG_CID` reader"]
pub struct R(crate::R<OTG_CID_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<OTG_CID_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<OTG_CID_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<OTG_CID_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `OTG_CID` writer"]
pub struct W(crate::W<OTG_CID_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<OTG_CID_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<OTG_CID_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<OTG_CID_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `PRODUCT_ID` reader - Product ID field"]
pub struct PRODUCT_ID_R(crate::FieldReader<u32, u32>);
impl PRODUCT_ID_R {
    pub(crate) fn new(bits: u32) -> Self {
        PRODUCT_ID_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PRODUCT_ID_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `PRODUCT_ID` writer - Product ID field"]
pub struct PRODUCT_ID_W<'a> {
    w: &'a mut W,
}
impl<'a> PRODUCT_ID_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Product ID field"]
    #[inline(always)]
    pub fn product_id(&self) -> PRODUCT_ID_R {
        PRODUCT_ID_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Product ID field"]
    #[inline(always)]
    pub fn product_id(&mut self) -> PRODUCT_ID_W {
        PRODUCT_ID_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "core ID register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [otg_cid](index.html) module"]
pub struct OTG_CID_SPEC;
impl crate::RegisterSpec for OTG_CID_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [otg_cid::R](R) reader structure"]
impl crate::Readable for OTG_CID_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [otg_cid::W](W) writer structure"]
impl crate::Writable for OTG_CID_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets OTG_CID to value 0x2000"]
impl crate::Resettable for OTG_CID_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0x2000
    }
}

==> rustc_1.89.0+dfsg1.orig.tar.xz: rustc-1.89.0-src/src/tools/rustc-perf/collector/compile-benchmarks/stm32f4-0.15.1/src/stm32f446/otg_fs_global/otg_cid.rs <==
#[doc = "Register `OTG_CID` reader"]
pub struct R(crate::R<OTG_CID_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<OTG_CID_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<OTG_CID_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<OTG_CID_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `OTG_CID` writer"]
pub struct W(crate::W<OTG_CID_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<OTG_CID_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<OTG_CID_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<OTG_CID_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `PRODUCT_ID` reader - Product ID field"]
pub type PRODUCT_ID_R = crate::FieldReader<u32, u32>;
#[doc = "Field `PRODUCT_ID` writer - Product ID field"]
pub type PRODUCT_ID_W<'a, const O: u8> = crate::FieldWriter<'a, u32, OTG_CID_SPEC, u32, u32, 32, O>;
impl R {
    #[doc = "Bits 0:31 - Product ID field"]
    #[inline(always)]
    pub fn product_id(&self) -> PRODUCT_ID_R {
        PRODUCT_ID_R::new(self.bits)
    }
}
impl W {
    #[doc = "Bits 0:31 - Product ID field"]
    #[inline(always)]
    pub fn product_id(&mut self) -> PRODUCT_ID_W<0> {
        PRODUCT_ID_W::new(self)
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "core ID register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [otg_cid](index.html) module"]
pub struct OTG_CID_SPEC;
impl crate::RegisterSpec for OTG_CID_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [otg_cid::R](R) reader structure"]
impl crate::Readable for OTG_CID_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [otg_cid::W](W) writer structure"]
impl crate::Writable for OTG_CID_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets OTG_CID to value 0x2000"]
impl crate::Resettable for OTG_CID_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0x2000
    }
}
